Learn R Programming

cem (version 1.0.142)

L1.meas: Evaluates L1 distance between multidimensional histograms

Description

Evaluates L1 distance between multidimensional histograms

Usage

L1.meas(group, data, drop=NULL, breaks = NULL, weights)

Arguments

group
the group variable
data
the data
drop
a vector of variable names in the data frame to ignore
breaks
a list of vectors of cutpoints; if not specified, automatic choice will be made
weights
weights

Value

  • An object of class L1.meas which is a list with the following fields
  • L1The numerical value of the L1 measure
  • breaksA list of cutpoints used to calculate the L1 measure
  • LCSThe numerical value of the Local Common Support proportion

Details

This function calculates the L1 distance on the k-dimensional histogram in order to measure the level of imbalance in a matching solution.

If breaks is not specified, the Scott automated bin calculation is used (which coarsens less than Sturges, which used in cem). Please refer to cem help page. In this case, breaks are used to calculate the L1 measure.

When choosing breaks for L1, a very fine coarsening (many cut points) produces values of L1 close to 1. A very mild coarsening (very fex cutpoints), is not able to discriminate, i.e. L1 close to 0 (particularly true when the number of observations is small with respect to the number of continuous variables). The L1.profile function shows how to compare matching solutions for any level of (i.e., without regard to) coarsening.

This code also calculate the Local Common Support (LCS) measure, which is the proportion of non empty k-dimensional cells of the histogram which contain at least one observation per group.

References

Stefano Iacus, Gary King, Giuseppe Porro, ``Matching for Casual Inference Without Balance Checking: Coarsened Exact Matching,'' http://gking.harvard.edu/files/abs/cem-abs.shtml

Examples

Run this code
data(LL)
L1.meas(LL$treated,LL, drop=c("treated","re78"))

Run the code above in your browser using DataLab