L1.meas(group, data, drop=NULL, breaks = NULL, weights)L1.meas which is a list with the following fieldsIf breaks is not specified, the Scott automated bin calculation
is used (which coarsens less than Sturges, which used in
cem). Please refer to cem help page. In
this case, breaks are used to calculate the L1 measure.
If breaks is missing, the default rule to calculate cutpoints
is the Scott's rule.
This code also calculate the Local Common Support (LCS) measure, which is the proportion of non empty k-dimensional cells of the histogram which contain at least one observation per group.
data(LL)
L1.meas(LL$treated,LL, drop=c("treated","re78"))Run the code above in your browser using DataLab