Learn R Programming

cem (version 1.0.44)

L1.meas: Evaluates L1 distance between multidimensional histograms

Description

Evaluates L1 distance between multidimensional histograms

Usage

L1.meas(group, data, drop=NULL, breaks = NULL, weights)

Arguments

group
the group variable
data
the data
drop
a vector of variable names in the data frame to ignore
breaks
a list of vectors of cutpoints; if not specified, automatic choice will be made
weights
weights

Value

  • An object of class L1.meas which is a list with the following fields
  • breaksA list of cutpoints used to calculate the L1 measure
  • valueThe numerical value of the L1 measure

Details

This function calculates the L1 distance on the k-dimensional histogram.

If breaks is not specified, the Scott automated bin calculation is used (which coarsens less than Sturges, which used in cem). Please refer to cem help page. In this case, breaks are used to calculate the L1 measure.

If breaks is missing, the default rule to calculate cutpoints is the Scott's rule.

References

Stefano Iacus, Gary King, Giuseppe Porro, ``Matching for Casual Inference Without Balance Checking,'' http://gking.harvard.edu/files/abs/cem-abs.shtml

Examples

Run this code
data(LL)
L1.meas(LL$treated,LL, drop=c("treated","re78"))

Run the code above in your browser using DataLab