This function calculates the L1 distance on the k-dimensional histogram.If breaks is not specified, the Scott automated bin calculation
is used (which coarsens less than Sturges, which used in
cem). Please refer to cem help page. In
this case, breaks are used to calculate the L1 measure.
If breaks is missing, the default rule to calculate cutpoints
is the Scott's rule.